@@ -88,7 +88,7 @@ def verify_config(filename = ""):
         #if CFG_DEBUG:print("D... config verified")
     except:
         #if CFG_DEBUG:
-        print("D... verification config FAILED")
+        print("X... verification config FAILED")
     return ok
 
 def get_config_file():
@@ -158,9 +158,9 @@ def bak_to_cfg(filenamebk="", filename = ""):
         os.rename(os.path.expanduser(cfgbak),
                   os.path.expanduser(cfg))
         #if CFG_DEBUG:print("D... config is recovered from:", cfgbak)
-    else:
+    #else:
         #if CFG_DEBUG:
-        print("D... bak config did not exist:", cfgbak,"no bak file recovery")
+        #print("D... bak config did not exist:", cfgbak,"no bak file recovery")
 
 
 def save_config(filenamesv="", filename = ""): # duplicit... filename overrides
@@ -223,11 +223,11 @@ def load_config(filename=""):
         return False
 
     #if CFG_DEBUG:
-    print("D... passed verification of:",cfg)
+    #print("D... passed verification of:",cfg)
     dicti = CONFIG
 
     #if CFG_DEBUG:
-    print("D... directly loading json:",cfg)
+    #print("D... directly loading json:",cfg)
     if os.path.isfile( os.path.expanduser(cfg)):
         with open(os.path.expanduser(cfg), "r") as f:
             dicti = json.load(f)
