@@ -385,7 +385,7 @@ class Camera(BaseCamera):
                     if substract_background:
                         # print("D... HERE I MUST DO subtraction of mask")
                         # print("D... HERE I MUST DO subtraction of mask")
-                        print("D... HERE I MUST DO subtraction of mask",speedx, speedy)
+                        # print("D... HERE I MUST DO subtraction of mask",speedx, speedy)
                         senh.subtract()
 
 
@@ -397,7 +397,7 @@ class Camera(BaseCamera):
                         save_foreground = False  # ONE SHOT
 
                     if mix_foreground:
-                        print("D... HERE I mix the foreground")
+                        # print("D... HERE I mix the foreground")
                         senh.mix()
 
 
